---
name: Bug report
about: Create a report to correct failures and improve our code
title: ''
labels: ''
assignees: ''
---
**Describe the bug**
Please provide a concise, clear description of the bug, as well as any available error logs.

**Please also include the following items to support reproducing the bug**
1. compilers (with versions)
2. Kokkos release or commit used (i.e., the sha1 number)
3. platform and backend
4. cmake configure command
5. output from cmake command
6. code needed to reproduce the bug
7. command line needed to reproduce the bug
7. please also attach the `KokkosCore_config.h` header file (generated during the build);
**Any additional info**
Please provide any additional context about the issue here.
